@@ -5,8 +5,8 @@ my $N_threads = $ARGV[0] || 2;
 
 use PDL;
 use PDL::Parallel::threads qw(retrieve_pdls);
-use PDL::Parallel::threads::SIMD qw(barrier_sync parallelize);
-zeroes(10_000_000)->share_as('test');
+use PDL::Parallel::threads::SIMD qw(parallel_sync parallelize parallel_id);
+zeroes(100_000_000)->share_as('test');
 use PDL::IO::FastRaw;
 mapfraw('foo.dat', {Creat => 1, Dims => [$N_threads], Datatype => double})
 	->share_as('mapped');
@@ -15,13 +15,13 @@ print "Main thread is about to rest for 5 seconds\n";
 sleep 5;
 
 parallelize {
-	my $tid = shift;
+	my $tid = parallel_id;
 	my ($piddle, $mapped) = retrieve_pdls('test', 'mapped');
 	
 	print "Thread id $tid is about to sleep for 5 seconds\n";
-	barrier_sync;
+	parallel_sync;
 	sleep 5;
-	barrier_sync;
+	parallel_sync;
 } $N_threads;
 
 
